@@ -6,9 +6,10 @@ use warnings;
 use parent 'RPi::WiringPi::Core';
 
 use RPi::WiringPi::Constant qw(:all);
+use RPi::WiringPi::LCD;
 use RPi::WiringPi::Pin;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 my $fatal_exit = 1;
 
@@ -33,21 +34,23 @@ sub new {
     $self = bless {%args}, $self;
 
     if (! $ENV{NO_BOARD}){
-        if ($self->_setup =~ /^w/){
-            $self->SUPER::setup();
-            $self->pin_map('wiringPi');
-        }
-        elsif ($self->_setup =~ /^g/){
-            $self->SUPER::setup_gpio();
-            $self->pin_map('GPIO');
-        }
-        elsif ($self->_setup =~ /^s/){
-            $self->SUPER::setup_sys();
-            $self->pin_map('BCM');
-        }
-        elsif ($self->_setup =~ /^p/){
-            $self->SUPER::setup_phys();
-            $self->pin_map('PHYS GPIO');
+        if (defined $self->{setup}){
+            if ($self->_setup =~ /^w/){
+                $self->SUPER::setup();
+                $self->pin_map('wiringPi');
+            }
+            elsif ($self->_setup =~ /^g/){
+                $self->SUPER::setup_gpio();
+                $self->pin_map('GPIO');
+            }
+            elsif ($self->_setup =~ /^s/){
+                $self->SUPER::setup_sys();
+                $self->pin_map('BCM');
+            }
+            elsif ($self->_setup =~ /^p/){
+                $self->SUPER::setup_phys();
+                $self->pin_map('PHYS GPIO');
+            }
         }
     }
     $self->_fatal_exit;
@@ -64,6 +67,11 @@ sub board {
     my $board = RPi::WiringPi::Board->new;
     return $board;
 }
+sub lcd {
+    my $self = shift;
+    my $lcd = RPi::WiringPi::LCD->new;
+    return $lcd;
+}
 
 # helper
 sub pin_map {
@@ -237,11 +245,6 @@ your script. This is for unit testing purposes only.
 
 =back
 
-=head2 board()
-
-Returns a L<RPi::WiringPi::Board> object which has access to various
-attributes of the Raspberry Pi physical board itself.
-
 =head2 pin($pin_num)
 
 Returns a L<RPi::WiringPi::Pin> object, mapped to a specified GPIO pin.
@@ -256,6 +259,16 @@ Mandatory: The pin number to attach to.
 
 =back
 
+=head2 board()
+
+Returns a L<RPi::WiringPi::Board> object which has access to various
+attributes of the Raspberry Pi physical board itself.
+
+=head2 lcd()
+
+Returns a L<RPi::WiringPi::LCD> object, which allows you to fully manipulate
+LCD displays connected to your Raspberry Pi.
+
 =head2 cleanup()
 
 Resets all registered pins back to default settings (off). It's important that
@@ -309,13 +322,13 @@ them.
 
 =over 4
 
-=item L<wiringPi|http://wiringpi.com> must be installed prior to installing/using
-this module.
+=item - L<wiringPi|http://wiringpi.com> must be installed prior to
+installing/using this module.
 
-=item By default, we use C<wiringPi>'s interpretation of GPIO pin mapping. See
-C<new> method to change this behaviour.
+=item - By default, we use C<wiringPi>'s interpretation of GPIO pin mapping.
+See C<new> method to change this behaviour.
 
-=item This module hijacks fatal errors with C<$SIG{__DIE__}>, as well as
+=item - This module hijacks fatal errors with C<$SIG{__DIE__}>, as well as
 C<$SIG{INT}>. This is so that in the case of a fatal error, the Raspberry Pi
 pins are never left in an inconsistent state. By default, we trap the C<die()>,
 reset all pins to their default (INPUT, LOW), then we C<exit()>. Look at the
